@@ -148,6 +148,7 @@ from dagster._core.definitions.decorators.schedule_decorator import (
 from dagster._core.definitions.decorators.sensor_decorator import (
     asset_sensor as asset_sensor,
     sensor as sensor,
+    multi_asset_sensor as multi_asset_sensor,
 )
 from dagster._core.definitions.dependency import (
     DependencyDefinition as DependencyDefinition,
@@ -297,9 +298,12 @@ from dagster._core.definitions.schedule_definition import (
 from dagster._core.definitions.sensor_definition import (
     AssetSensorDefinition as AssetSensorDefinition,
     DefaultSensorStatus as DefaultSensorStatus,
+    MultiAssetSensorDefinition as MultiAssetSensorDefinition,
+    MultiAssetSensorEvaluationContext as MultiAssetSensorEvaluationContext,
     SensorDefinition as SensorDefinition,
     SensorEvaluationContext as SensorEvaluationContext,
     build_sensor_context as build_sensor_context,
+    build_multi_asset_sensor_context as build_multi_asset_sensor_context,
 )
 from dagster._core.definitions.source_asset import (
     SourceAsset as SourceAsset,
@@ -427,6 +431,11 @@ from dagster._core.executor.base import (
 from dagster._core.executor.init import (
     InitExecutorContext as InitExecutorContext,
 )
+
+from dagster._core.host_representation.selector import (
+    RepositorySelector as RepositorySelector,
+    JobSelector as JobSelector,
+)
 from dagster._core.instance import (
     DagsterInstance as DagsterInstance,
 )
@@ -436,7 +445,8 @@ from dagster._core.launcher.default_run_launcher import (
 from dagster._core.log_manager import (
     DagsterLogManager as DagsterLogManager,
 )
-from dagster._core.storage.event_log.base import (
+
+from dagster._core.event_api import (
     EventLogRecord as EventLogRecord,
     EventRecordsFilter as EventRecordsFilter,
     RunShardedEventsCursor as RunShardedEventsCursor,
@@ -506,6 +516,9 @@ from dagster._loggers import (
     default_system_loggers as default_system_loggers,
     json_console_logger as json_console_logger,
 )
+from dagster._core.execution.context.system import (
+    DagsterTypeLoaderContext as DagsterTypeLoaderContext,
+)
 from dagster._serdes.serdes import (
     deserialize_value as deserialize_value,
     serialize_value as serialize_value,
@@ -522,7 +535,8 @@ from dagster._utils.backcompat import (
 from dagster._utils.log import (
     get_dagster_logger as get_dagster_logger,
 )
-from dagster._utils.test import (
+
+from dagster._utils.dagster_type import (
     check_dagster_type as check_dagster_type,
 )
 
@@ -551,6 +565,7 @@ from dagster._utils.backcompat import deprecation_warning, rename_warning
 
 if TYPE_CHECKING:
     # pylint:disable=reimported
+    from dagster._core.execution.context.system import DagsterTypeMaterializerContext
     from dagster._core.types.config_schema import DagsterTypeMaterializer, dagster_type_materializer
 
     # pylint:enable=reimported
@@ -566,6 +581,11 @@ _DEPRECATED: Final[Mapping[str, TypingTuple[str, str, str]]] = {
         "1.1.0",
         "Instead, use an IOManager.",
     ),
+    "DagsterTypeMaterializerContext": (
+        "dagster._core.execution.context.system",
+        "1.1.0",
+        "Instead, use an IOManager.",
+    ),
 }
 
 # Example Deprecated Renamed Entry:
