@@ -1,25 +1,12 @@
 from functools import update_wrapper
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Set,
-    Union,
-    overload,
-)
+from typing import TYPE_CHECKING, Any, Callable, Dict, Mapping, Optional, Set, Union, overload
 
 import dagster._check as check
 from dagster._config import UserConfigSchema
 from dagster._core.decorator_utils import format_docstring_for_description
-from dagster._core.errors import DagsterInvariantViolationError
 
-from ..input import In, InputDefinition
-from ..output import Out, OutputDefinition
+from ..input import In
+from ..output import Out
 from ..policy import RetryPolicy
 from ..utils import DEFAULT_OUTPUT
 from .solid_decorator import DecoratedSolidFunction, NoContextDecoratedSolidFunction
@@ -32,8 +19,6 @@ class _Op:
     def __init__(
         self,
         name: Optional[str] = None,
-        input_defs: Optional[Sequence[InputDefinition]] = None,
-        output_defs: Optional[Sequence[OutputDefinition]] = None,
         description: Optional[str] = None,
         required_resource_keys: Optional[Set[str]] = None,
         config_schema: Optional[Union[Any, Dict[str, Any]]] = None,
@@ -45,10 +30,6 @@ class _Op:
         out: Optional[Union[Out, Mapping[str, Out]]] = None,
     ):
         self.name = check.opt_str_param(name, "name")
-        self.input_defs = check.opt_nullable_sequence_param(
-            input_defs, "input_defs", of_type=InputDefinition
-        )
-        self.output_defs = output_defs
         self.decorator_takes_context = check.bool_param(
             decorator_takes_context, "decorator_takes_context"
         )
@@ -79,16 +60,6 @@ class _Op:
             else NoContextDecoratedSolidFunction(decorated_fn=fn)
         )
 
-        if self.ins and self.input_defs:
-            raise DagsterInvariantViolationError(
-                f"Error constructing op '{self.name}': cannot provide both ins and input_defs arguments."
-            )
-
-        if self.out and self.output_defs:
-            raise DagsterInvariantViolationError(
-                f"Error constructing op '{self.name}': cannot provide both out and output_defs arguments."
-            )
-
         outs: Optional[Mapping[str, Out]] = None
         if self.out is not None and isinstance(self.out, Out):
             outs = {DEFAULT_OUTPUT: self.out}
@@ -106,20 +77,19 @@ class _Op:
             tags=self.tags,
             version=self.version,
             retry_policy=self.retry_policy,
-            input_defs=self.input_defs,
-            output_defs=self.output_defs,
         )
         update_wrapper(op_def, compute_fn.decorated_fn)
         return op_def
 
 
 @overload
-def op(name: Callable[..., Any]) -> "OpDefinition":
+def op(compute_fn: Callable[..., Any]) -> "OpDefinition":
     ...
 
 
 @overload
 def op(
+    *,
     name: Optional[str] = ...,
     description: Optional[str] = ...,
     ins: Optional[Dict[str, In]] = ...,
@@ -129,14 +99,14 @@ def op(
     tags: Optional[Dict[str, Any]] = ...,
     version: Optional[str] = ...,
     retry_policy: Optional[RetryPolicy] = ...,
-    input_defs: Optional[List[InputDefinition]] = ...,
-    output_defs: Optional[List[OutputDefinition]] = ...,
 ) -> _Op:
     ...
 
 
 def op(
-    name: Optional[Union[Callable[..., Any], str]] = None,
+    compute_fn: Optional[Callable] = None,
+    *,
+    name: Optional[str] = None,
     description: Optional[str] = None,
     ins: Optional[Dict[str, In]] = None,
     out: Optional[Union[Out, Mapping[str, Out]]] = None,
@@ -145,8 +115,6 @@ def op(
     tags: Optional[Dict[str, Any]] = None,
     version: Optional[str] = None,
     retry_policy: Optional[RetryPolicy] = None,
-    input_defs: Optional[List[InputDefinition]] = None,
-    output_defs: Optional[List[OutputDefinition]] = None,
 ) -> Union["OpDefinition", _Op]:
     """
     Create an op with the specified parameters from the decorated function.
@@ -191,10 +159,6 @@ def op(
             the same version if and only if they deterministically produce the same outputs when
             provided the same inputs.
         retry_policy (Optional[RetryPolicy]): The retry policy for this op.
-        input_defs (Optional[List[InputDefinition]]):
-            (legacy) Preserved to ease migration from :py:class:`solid`. Can be used in place of ins argument.
-        output_defs (Optional[List[OutputDefinition]]):
-            (legacy) Preserved to ease migration from :py:class:`solid`. Can be used in place of out argument.
 
     Examples:
 
@@ -222,23 +186,18 @@ def op(
                 return 'cool', 4
     """
 
-    # This case is for when decorator is used bare, without arguments. e.g. @op versus @op()
-    if callable(name):
-        check.invariant(input_defs is None)
-        check.invariant(output_defs is None)
+    if compute_fn is not None:
         check.invariant(description is None)
         check.invariant(config_schema is None)
         check.invariant(required_resource_keys is None)
         check.invariant(tags is None)
         check.invariant(version is None)
 
-        return _Op()(name)
+        return _Op()(compute_fn)
 
     return _Op(
         name=name,
         description=description,
-        input_defs=input_defs,
-        output_defs=output_defs,
         config_schema=config_schema,
         required_resource_keys=required_resource_keys,
         tags=tags,
