@@ -130,12 +130,13 @@ class _Repository:
 
 
 @overload
-def repository(name: Callable[..., Any]) -> RepositoryDefinition:
+def repository(definitions_fn: Callable[..., Any]) -> RepositoryDefinition:
     ...
 
 
 @overload
 def repository(
+    *,
     name: Optional[str] = ...,
     description: Optional[str] = ...,
     default_executor_def: Optional[ExecutorDefinition] = ...,
@@ -145,7 +146,9 @@ def repository(
 
 
 def repository(
-    name: Optional[Union[str, Callable[..., Any]]] = None,
+    definitions_fn: Optional[Callable[..., Any]] = None,
+    *,
+    name: Optional[str] = None,
     description: Optional[str] = None,
     default_executor_def: Optional[ExecutorDefinition] = None,
     default_logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
@@ -154,7 +157,7 @@ def repository(
 
     The decorated function should take no arguments and its return value should one of:
 
-    1. ``List[Union[JobDefinition, PipelineDefinition, PartitionSetDefinition, ScheduleDefinition, SensorDefinition]]``.
+    1. ``List[Union[JobDefinition, ScheduleDefinition, SensorDefinition]]``.
     Use this form when you have no need to lazy load pipelines or other definitions. This is the
     typical use case.
 
@@ -164,8 +167,6 @@ def repository(
 
         {
             'jobs': Dict[str, Callable[[], JobDefinition]],
-            'pipelines': Dict[str, Callable[[], PipelineDefinition]],
-            'partition_sets': Dict[str, Callable[[], PartitionSetDefinition]],
             'schedules': Dict[str, Callable[[], ScheduleDefinition]]
             'sensors': Dict[str, Callable[[], SensorDefinition]]
         }
@@ -276,11 +277,11 @@ def repository(
             return ComplexRepositoryData('some_directory')
 
     """
-    if callable(name):
+    if definitions_fn is not None:
         check.invariant(description is None)
-        check.invariant(len(get_function_params(name)) == 0)
+        check.invariant(len(get_function_params(definitions_fn)) == 0)
 
-        return _Repository()(name)
+        return _Repository()(definitions_fn)
 
     return _Repository(
         name=name,
