@@ -3,6 +3,7 @@ from functools import update_wrapper
 from typing import TYPE_CHECKING, Callable, Optional, Sequence
 
 import dagster._check as check
+from dagster._annotations import experimental
 from dagster._core.errors import DagsterInvariantViolationError
 
 from ...errors import DagsterInvariantViolationError
@@ -11,6 +12,8 @@ from ..sensor_definition import (
     AssetMaterializationFunction,
     AssetSensorDefinition,
     DefaultSensorStatus,
+    MultiAssetMaterializationFunction,
+    MultiAssetSensorDefinition,
     RawSensorEvaluationFunction,
     RunRequest,
     SensorDefinition,
@@ -40,7 +43,7 @@ def sensor(
     2. Return a list of `RunRequest` objects.
     3. Return a `SkipReason` object, providing a descriptive message of why no runs were requested.
     4. Return nothing (skipping without providing a reason)
-    5. Yield a `SkipReason` or yield one ore more `RunRequest` objects.
+    5. Yield a `SkipReason` or yield one or more `RunRequest` objects.
 
     Takes a :py:class:`~dagster.SensorEvaluationContext`.
 
@@ -99,7 +102,7 @@ def asset_sensor(
     2. Return a list of `RunRequest` objects.
     3. Return a `SkipReason` object, providing a descriptive message of why no runs were requested.
     4. Return nothing (skipping without providing a reason)
-    5. Yield a `SkipReason` or yield one ore more `RunRequest` objects.
+    5. Yield a `SkipReason` or yield one or more `RunRequest` objects.
 
     Takes a :py:class:`~dagster.SensorEvaluationContext` and an EventLogEntry corresponding to an
     AssetMaterialization event.
@@ -156,3 +159,83 @@ def asset_sensor(
         )
 
     return inner
+
+
+@experimental
+def multi_asset_sensor(
+    asset_keys: Sequence[AssetKey],
+    *,
+    job_name: Optional[str] = None,
+    name: Optional[str] = None,
+    minimum_interval_seconds: Optional[int] = None,
+    description: Optional[str] = None,
+    job: Optional[ExecutableDefinition] = None,
+    jobs: Optional[Sequence[ExecutableDefinition]] = None,
+    default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
+) -> Callable[[MultiAssetMaterializationFunction,], MultiAssetSensorDefinition,]:
+    """
+    Creates an asset sensor that can monitor multiple assets
+
+    The decorated function is used as the asset sensor's evaluation
+    function.  The decorated function may:
+
+    1. Return a `RunRequest` object.
+    2. Return a list of `RunRequest` objects.
+    3. Return a `SkipReason` object, providing a descriptive message of why no runs were requested.
+    4. Return nothing (skipping without providing a reason)
+    5. Yield a `SkipReason` or yield one ore more `RunRequest` objects.
+
+    Takes a :py:class:`~dagster.MultiAssetSensorEvaluationContext`.
+
+    Args:
+        asset_keys (Sequence[AssetKey]): The asset_keys this sensor monitors.
+        name (Optional[str]): The name of the sensor. Defaults to the name of the decorated
+            function.
+        minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
+            between sensor evaluations.
+        description (Optional[str]): A human-readable description of the sensor.
+        job (Optional[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]): The
+            job to be executed when the sensor fires.
+        jobs (Optional[Sequence[Union[GraphDefinition, JobDefinition, UnresolvedAssetJobDefinition]]]):
+            (experimental) A list of jobs to be executed when the sensor fires.
+        default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
+            status can be overridden from Dagit or via the GraphQL API.
+    """
+
+    check.opt_str_param(name, "name")
+
+    def inner(fn: MultiAssetMaterializationFunction) -> MultiAssetSensorDefinition:
+        check.callable_param(fn, "fn")
+        sensor_name = name or fn.__name__
+
+        def _wrapped_fn(context):
+            result = fn(context)
+
+            if inspect.isgenerator(result) or isinstance(result, list):
+                for item in result:
+                    yield item
+            elif isinstance(result, (RunRequest, SkipReason)):
+                yield result
+
+            elif result is not None:
+                raise DagsterInvariantViolationError(
+                    (
+                        "Error in sensor {sensor_name}: Sensor unexpectedly returned output "
+                        "{result} of type {type_}.  Should only return SkipReason or "
+                        "RunRequest objects."
+                    ).format(sensor_name=sensor_name, result=result, type_=type(result))
+                )
+
+        return MultiAssetSensorDefinition(
+            name=sensor_name,
+            asset_keys=asset_keys,
+            job_name=job_name,
+            asset_materialization_fn=_wrapped_fn,
+            minimum_interval_seconds=minimum_interval_seconds,
+            description=description,
+            job=job,
+            jobs=jobs,
+            default_status=default_status,
+        )
+
+    return inner
