@@ -173,12 +173,21 @@ class JobDefinition(PipelineDefinition):
         partitioned_config = None
 
         if partitions_def:
-            if isinstance(config, (ConfigMapping, PartitionedConfig)):
-                check.failed(
-                    "Can't supply a ConfigMapping or PartitionedConfig for 'config' when 'partitions_def' is supplied."
+            check.invariant(
+                not isinstance(config, ConfigMapping),
+                "Can't supply a ConfigMappi/ng for 'config' when 'partitions_def' is supplied.",
+            )
+
+            if isinstance(config, PartitionedConfig):
+                check.invariant(
+                    config.partitions_def == partitions_def,
+                    "Can't supply a PartitionedConfig for 'config' with a different "
+                    "PartitionsDefinition than supplied for 'partitions_def'.",
                 )
-            hardcoded_config = config if config else {}
-            partitioned_config = PartitionedConfig(partitions_def, lambda _: hardcoded_config)
+                partitioned_config = config
+            else:
+                hardcoded_config = config if config else {}
+                partitioned_config = PartitionedConfig(partitions_def, lambda _: hardcoded_config)
 
         if isinstance(config, ConfigMapping):
             config_mapping = config
@@ -573,7 +582,9 @@ class JobDefinition(PipelineDefinition):
             else partition_set.tags_for_partition(partition)
         )
 
-        return RunRequest(run_key=run_key, run_config=run_config, tags=run_request_tags)
+        return RunRequest(
+            run_key=run_key, run_config=run_config, tags=run_request_tags, job_name=self.name
+        )
 
     @public
     def with_hooks(self, hook_defs: AbstractSet[HookDefinition]) -> "JobDefinition":
